#!/bin/sh
# Last modified 2022-09-19

# Set a variable for the application name
APP="Suitcase Fusion"

##
## Displays some information about the script
##

cat <<LETTERHEAD
*
* Suitcase Fusion session cleaning script
* This removes preferences and session information for Suitcase Fusion v21 and v22
* on Mac OS X 10.15 through macOS 12
* 
LETTERHEAD

# Stop the application
echo "Shutting down the $APP application..."
SF_APP=$(pgrep -f "Suitcase Fusion.app/Contents/MacOS/Suitcase Fusion")
if [ -n "$SF_APP" ]; then
    kill -s HUP "$SF_APP" > /dev/null 2>&1
	# Sleep for a few seconds to let things shut down completely
	sleep 5
	if [ -n "$SF_APP" ]; then
		kill -s KILL "$SF_APP" > /dev/null 2>&1
		sleep 5
	fi
fi

# Stop the QuickMatch process (FMRenderer)
echo "Shutting down FMRenderer..."

QM_PROCESS=$(pgrep -f "Suitcase Fusion.app/Contents/MacOS/Resources/FMRenderer")
if [ -n "$QM_PROCESS" ]; then
	kill -s HUP "$QM_PROCESS" > /dev/null 2>&1
	sleep 3
	if [ -n "$QM_PROCESS" ]; then
		kill -s KILL "$QM_PROCESS" > /dev/null 2>&1
		sleep 3
	fi
fi

echo "Done"

# Stop the FMCore process
echo "Shutting down the $APP type core..."

FMCORE=$(pgrep -f "Suitcase Fusion.app/Contents/MacOS/Resources/FMCore")

if [ -n "$FMCORE" ]; then
	kill -s HUP "$FMCORE" > /dev/null 2>&1
	sleep 5
	while [ -n "$FMCORE" ]; do
		kill -s KILL "$FMCORE" > /dev/null 2>&1
		FMCORE=$(pgrep -f "Suitcase Fusion.app/Contents/MacOS/Resources/FMCore")
		sleep 3
	done
fi

echo "Done"

##
## Remove user preferences and session files for the current user account
##

echo "Removing $APP preferences and session files for the current user account..."

rm -rf "$HOME/Library/Extensis/com.extensis.FMCore-LaunchInfo.conf" > /dev/null 2>&1
# Remove application cache and session information
rm -rf "$HOME/.Extensis" > /dev/null 2>&1
rm -rf "$HOME/Library/Caches/FMCore" > /dev/null 2>&1
rm -rf "$HOME/Library/Caches/com.extensis.FMCore" > /dev/null 2>&1
rm -rf "$HOME/Library/Caches/com.extensis.SuitcaseFusion" > /dev/null 2>&1

if [ -e "$HOME/Library/Preferences/com.extensis.SuitcaseFusion.plist" ]; then
	# Capture the vault location in case the user has customized it
	echo "Getting the vault location..."
	VAULT_LOC=$(defaults read com.extensis.SuitcaseFusion vault.path)
	# Remove the contents of the prefs file
	echo "Removing the $APP preferences..."
	defaults delete com.extensis.SuitcaseFusion
	# Put the vault location back
	echo "Restoring the vault location..."
	defaults write com.extensis.SuitcaseFusion vault.path "$VAULT_LOC"
fi

# Remove preferences files for legacy versions
rm -rf "$HOME/Library/Preferences/com.extensis.*.lockfile" > /dev/null 2>&1
rm -rf "$HOME/Library/Preferences/com.extensis.SFPrefPane.plist" > /dev/null 2>&1
rm -rf "$HOME/Library/Preferences/com.extensis.Suitcase.plist" > /dev/null 2>&1
rm -rf "$HOME/Library/Preferences/com.extensis.suitcase.plugins.*.plist" > /dev/null 2>&1
rm -rf "$HOME/Library/Preferences/com.extensis.SuitcaseFusion1ExportTool.plist" > /dev/null 2>&1
rm -rf "$HOME/Library/Preferences/com.extensis.SuitcaseFusion2*" > /dev/null 2>&1
rm -rf "$HOME/Library/Preferences/com.extensis.SuitcaseFusion3*" > /dev/null 2>&1
rm -rf "$HOME/Library/Preferences/com.extensis.SuitcaseFusion4*" > /dev/null 2>&1
rm -rf "$HOME/Library/Preferences/com.extensis.SuitcaseFusion5*" > /dev/null 2>&1
rm -rf "$HOME/Library/Preferences/com.extensis.SuitcaseFusion6*" > /dev/null 2>&1

echo "Preference and session files for $APP have been removed. You can close this window."

exit
